# tamr-toolbox
The Tamr Toolbox is a Python library created to provide a simple interface for common interactions with Tamr and common data workflows that include Tamr. The more specialized [Tamr Python Client](https://github.com/Datatamer/tamr-client) library is used for direct interactions with Tamr in both the development of the Tamr Toolbox and in the recommended use of the Tamr Toolbox.

__Releases:__ https://github.com/Datatamer/tamr-toolbox/releases 

__Documentation Home:__ https://datatamer.github.io/tamr-toolbox/latest/

__Installation:__ https://datatamer.github.io/tamr-toolbox/latest/installation.html

__Examples:__ https://datatamer.github.io/tamr-toolbox/latest/examples.html
